@@ -1,5 +1,5 @@
 /* gpa.h  -  main header
- *	Copyright (C) 2000 Free Software Foundation, Inc.
+ *	Copyright (C) 2000, 2001 G-N-U GmbH.
  *
  * This file is part of GPA
  *
@@ -26,10 +26,7 @@
 #include <gpapa.h>
 #include "xmalloc.h"
 #include "logging.h"
-/*!!!
-#include <pgg.h>
-!!!*/
-#define N_(a)	(a)
+
 #ifdef USE_SIMPLE_GETTEXT
   int set_gettext_file( const char *filename );
   const char *gettext( const char *msgid );
@@ -58,32 +55,25 @@
 
 
 
-struct {
+typedef struct {
     int verbose;
     int quiet;
     unsigned int debug;
     char *homedir;
     char **keyserver_names;
-} opt;
-
+} GPAOptions;
+extern GPAOptions gpa_options;
 
 
 extern GtkWidget *global_windowMain;
 extern GtkWidget *global_windowTip;
-extern GList *global_tempWindows;
-extern gboolean global_noTips;
 extern GpapaAction global_lastCallbackResult;
 extern gchar *global_keyserver;
 extern GList *global_defaultRecipients;
-extern gchar *global_homeDirectory;
-extern gchar *global_defaultKey;
 
 extern GtkWidget *gpa_get_global_clist_file (void);
 extern void gpa_callback (GpapaAction action, gpointer actiondata,
 			  gpointer calldata);
-extern void gpa_switch_tips (void);
-extern void gpa_windowTip_init (void);
-extern void gpa_windowTip_show (gchar * text);
 extern void sigs_append (gpointer data, gpointer userData);
 extern void gpa_selectRecipient (GtkWidget * clist, gint row, gint column,
 				 GdkEventButton * event, gpointer userData);
@@ -93,4 +83,19 @@ extern void gpa_removeRecipients (gpointer param);
 extern void gpa_addRecipients (gpointer param);
 extern void gpa_recipientWindow_close (gpointer param);
 
+gboolean gpa_simplified_ui (void);
+void gpa_set_simplified_ui (gboolean value);
+
+gchar * gpa_default_key (void);
+void gpa_set_default_key (gchar * key);
+void gpa_update_default_key (void);
+
+void gpa_open_keyring_editor (void);
+void gpa_open_filemanager (void);
+GtkWidget * gpa_get_keyring_editor (void);
+GtkWidget * gpa_get_filenamager (void);
+
+typedef void (*GPADefaultKeyChanged) (gpointer user_data);
+
+
 #endif /*GPA_H */
